@@ -29,7 +29,7 @@ from .login_manager import LoginManager, LoginManagerProtocol, requires_login
 
 logger = logging.getLogger(__name__)
 
-_FUNCX_HOME = os.path.join("~", ".funcx")
+_FUNCX_HOME = os.path.join("~", ".globus_compute")
 
 
 class Client:
@@ -468,6 +468,7 @@ class Client:
         endpoint_id,
         metadata=None,
         multi_tenant=False,
+        display_name=None,
     ):
         """Register an endpoint with the Globus Compute service.
 
@@ -492,6 +493,7 @@ class Client:
             endpoint_id=endpoint_id,
             metadata=metadata,
             multi_tenant=multi_tenant,
+            display_name=display_name,
         )
         return r.data
 
